@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2021-03-30
+# Release 2021-04-14
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.4.6
+MAKERESOLVEDEB_VERSION=1.5.0
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -29,7 +29,7 @@ copy_object() {
 }
 
 assert_object() {
-    if ! [[ -e "$1" ]] ; then
+    if [[ ! -e "$1" ]] ; then
 	echo "[ERROR: MISSING] $1"
 	ERRORS=$((ERRORS+1))
     fi
@@ -47,7 +47,7 @@ create_directory() {
 	mkdir -p "$1"
 	chmod 755 "$1"
     fi
-    if ! [[ -w "$1" ]] ; then
+    if [[ ! -w "$1" ]] ; then
 	echo "[ERROR: DIRECTORY NOT WRITABLE] $1"
 	ERRORS=$((ERRORS+1))
     fi
@@ -137,7 +137,9 @@ process15() {
     copy_object ${UNPACK_DIR}/graphics ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/libs ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/LUT ${RESOLVE_BASE_DIR}
-    copy_object ${UNPACK_DIR}/Onboarding ${RESOLVE_BASE_DIR}
+    if [[ -z "$SKIP_ONBOARDING" ]]; then
+	copy_object ${UNPACK_DIR}/Onboarding ${RESOLVE_BASE_DIR}
+    fi
     copy_object ${UNPACK_DIR}/plugins ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/UI_Resource ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/scripts/script.checkfirmware ${RESOLVE_BASE_DIR}/scripts/
@@ -219,10 +221,11 @@ process16() {
     copy_object ${UNPACK_DIR}/graphics ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/libs ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/LUT ${RESOLVE_BASE_DIR}
-    copy_object ${UNPACK_DIR}/Onboarding ${RESOLVE_BASE_DIR}
+    if [[ -z "$SKIP_ONBOARDING" ]]; then
+	copy_object ${UNPACK_DIR}/Onboarding ${RESOLVE_BASE_DIR}
+    fi
     copy_object ${UNPACK_DIR}/plugins ${RESOLVE_BASE_DIR}
-    if ! [[ "$RESOLVE_VERSION" == 16.0b* ]];
-    then
+    if [[ ! "$RESOLVE_VERSION" == 16.0b* ]]; then
 	copy_object ${UNPACK_DIR}/Technical\ Documentation ${RESOLVE_BASE_DIR}
     fi
     copy_object ${UNPACK_DIR}/UI_Resource ${RESOLVE_BASE_DIR}
@@ -312,7 +315,9 @@ process17() {
     copy_object ${UNPACK_DIR}/graphics ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/libs ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/LUT ${RESOLVE_BASE_DIR}
-    copy_object ${UNPACK_DIR}/Onboarding ${RESOLVE_BASE_DIR}
+    if [[ -z "$SKIP_ONBOARDING" ]]; then
+	copy_object ${UNPACK_DIR}/Onboarding ${RESOLVE_BASE_DIR}
+    fi
     copy_object ${UNPACK_DIR}/plugins ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/Technical\ Documentation ${RESOLVE_BASE_DIR}
     copy_object ${UNPACK_DIR}/UI_Resource ${RESOLVE_BASE_DIR}
@@ -376,7 +381,10 @@ EOF
 }
 
 process1617braw() {
-    if ! [[ -e ${UNPACK_DIR}/BlackmagicRAWPlayer ]]; then
+    if [[ ! -z "$SKIP_BRAW" ]]; then
+	return;
+    fi
+    if [[ ! -e ${UNPACK_DIR}/BlackmagicRAWPlayer ]]; then
 	return;
     fi
     echo "Adding BlackmagicRAWPlayer"
@@ -399,7 +407,7 @@ StartupNotify=true
 Categories=AudioVideo
 EOF
 
-    if ! [[ -e ${UNPACK_DIR}/BlackmagicRAWSpeedTest ]]; then
+    if [[ ! -e ${UNPACK_DIR}/BlackmagicRAWSpeedTest ]]; then
 	return;
     fi
     echo "Adding BlackmagicRAWSpeedTest"
@@ -479,6 +487,14 @@ udevadm trigger
 EOF
 }
 
+print_usage() {
+    echo "Usage: $0 <DaVinci_Resolve_*_Linux.run>"
+    echo "Advanced options:"
+    echo "  -h | --help       Display this help"
+    echo "  --skip-onboarding Exclude Onboarding feature"
+    echo "  --skip-braw       Exclude BRAW Player and Speed Test"
+}
+
 echo "MakeResolveDeb ${MAKERESOLVEDEB_VERSION}"
 
 # Warn if running as root
@@ -489,30 +505,54 @@ then
     echo
 fi
 
-# Check argument
-case $1 in
-    *.run)
-	INSTALLER_ARCHIVE=$(basename "$1")
-	FILENAMEP1=$(echo $INSTALLER_ARCHIVE | cut -d'_' -f1 -)
-	FILENAMEP2=$(echo $INSTALLER_ARCHIVE | cut -d'_' -f2 -)
-	FILENAMEP3=$(echo $INSTALLER_ARCHIVE | cut -d'_' -f3 -)
-	FILENAMEP4=$(echo $INSTALLER_ARCHIVE | cut -d'_' -f4 -)
-	FILENAMEP5=$(echo $INSTALLER_ARCHIVE | cut -d'_' -f5 -)
-	;;
-    *)
-	echo "Usage: $0 <DaVinci_Resolve_*_Linux.run>"
-	exit 1
-	;;
-esac
-
-# Check if file exists
-if [[ ! -e $INSTALLER_ARCHIVE ]];
+# Parse arguments
+for arg in "$@"
+do
+    case $arg in
+	-h|--help)
+	    print_usage
+	    exit 1
+	    ;;
+        --skip-onboarding)
+            SKIP_ONBOARDING="yes"
+            shift
+            ;;
+        --skip-braw)
+            SKIP_BRAW="yes"
+            shift
+            ;;
+        -*|--*)
+            echo "[ERROR] Unknown argument '$1'"
+	    exit 1
+            ;;
+        *)
+	    if [[ -z "$INSTALLER_ARCHIVE" ]]; then
+		INSTALLER_ARCHIVE="$1"
+		shift
+	    else
+		echo "[ERROR] Only one installer archive file may be specified"
+		exit 1
+	    fi
+            ;;
+    esac
+done
+if [[ -z "$INSTALLER_ARCHIVE" ]]; then
+    echo "No installer archive file specified"
+    print_usage
+    exit 1
+fi
+if [[ ! -e "$INSTALLER_ARCHIVE" ]] || [[ "$INSTALLER_ARCHIVE" != $(basename $INSTALLER_ARCHIVE) ]];
 then
-    echo "[ERROR] File does not exist or is located outside the working directory"
+    echo "[ERROR] ${INSTALLER_ARCHIVE} does not exist or is located outside the working directory"
     exit 1
 fi
 
 # Validate and parse archive name
+FILENAMEP1=$(echo $INSTALLER_ARCHIVE | cut -d'_' -f1 -)
+FILENAMEP2=$(echo $INSTALLER_ARCHIVE | cut -d'_' -f2 -)
+FILENAMEP3=$(echo $INSTALLER_ARCHIVE | cut -d'_' -f3 -)
+FILENAMEP4=$(echo $INSTALLER_ARCHIVE | cut -d'_' -f4 -)
+FILENAMEP5=$(echo $INSTALLER_ARCHIVE | cut -d'_' -f5 -)
 if [[ "$FILENAMEP1" != "DaVinci" ]] || [[ "$FILENAMEP2" != "Resolve" ]];
 then
     echo "[ERROR] File does not look like a valid DaVinci Resolve installer archive"
